{% include 'head.html' %}
<div class="container">
    <div class="column">
        <p>Welcome to Wordlette! Your site needs a little bit of setup before it'll be ready to use.</p>
    </div>
</div>
{% include "foot.html" %}
